pub enum NodeManagerRequest {
AddNode {
node: Node2,
controller: ServerEnd<NodeControllerMarker>,
node_ref: Option<ServerEnd<NodeMarker>>,
responder: NodeManagerAddNodeResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: NodeManagerControlHandle,
method_type: MethodType,
},
}Expand description
Protocol through which a client can add a Node2 to the driver topology.
Variants
AddNode
Adds a Node2 to the driver framework.
Fields

controller: ServerEnd<NodeControllerMarker>
node_ref: Option<ServerEnd<NodeMarker>>
responder: NodeManagerAddNodeResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: NodeManagerControlHandle
method_type: MethodTypeImplementations
Sourceimpl NodeManagerRequest
impl NodeManagerRequest
pub fn into_add_node( self, ) -> Option<(Node2, ServerEnd<NodeControllerMarker>, Option<ServerEnd<NodeMarker>>, NodeManagerAddNodeResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL