pub enum NodeRequest {
AddChild {
args: NodeAddArgs,
controller: ServerEnd<NodeControllerMarker>,
node: Option<ServerEnd<NodeMarker>>,
responder: NodeAddChildResponder,
},
ProvideResource {
resource: ResourceArgs,
controller: ServerEnd<ResourceControllerMarker>,
responder: NodeProvideResourceResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: NodeControlHandle,
method_type: MethodType,
},
}Expand description
Protocol through which a driver manages a node that it is bound to.
Drivers should maintain their client connection to the node. Dropping
the client connection while the driver is running will cause the
driver framework to remove the driver and node from the topology.
If the driver has set host_restart_on_crash to “true” in their
component manifest, dropping the connection will initiate a restart of
the driver host and driver.
Variants
AddChild
Adds a child node to this node.
If node is present, this driver takes responsibility for binding to
the newly created child. Otherwise, the driver framework will locate an
appropriate driver to bind the child to.
Fields
args: NodeAddArgscontroller: ServerEnd<NodeControllerMarker>node: Option<ServerEnd<NodeMarker>>responder: NodeAddChildResponderProvideResource
Provides a resource that other nodes can depend on. The lifetime of the
provided resource is tied to the controller client connection. Dropping
the client connection will cause the resource to be removed.
Fields
resource: ResourceArgscontroller: ServerEnd<ResourceControllerMarker>responder: NodeProvideResourceResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: NodeControlHandlemethod_type: MethodTypeImplementations
Sourceimpl NodeRequest
impl NodeRequest
pub fn into_add_child( self, ) -> Option<(NodeAddArgs, ServerEnd<NodeControllerMarker>, Option<ServerEnd<NodeMarker>>, NodeAddChildResponder)>
pub fn into_provide_resource( self, ) -> Option<(ResourceArgs, ServerEnd<ResourceControllerMarker>, NodeProvideResourceResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL