pub struct Dependency {
pub selector: Option<Selector>,
pub tags: Option<Vec<ResourceProperty>>,
/* private fields */
}Expand description
Represents a dependency that a node has on a resource.
The dependency is resolved by matching a resource against the selector’s constraints.
Fields
selector: Option<Selector>The resources must match the selector’s constraints to be depended on.
Additional properties tagged to the resource for driver binding