DriverInfo

Struct DriverInfo 

pub struct DriverInfo {
    pub url: Option<String>,
    pub name: Option<String>,
    pub colocate: Option<bool>,
    pub package_type: Option<DriverPackageType>,
    pub is_fallback: Option<bool>,
    pub device_categories: Option<Vec<DeviceCategory>>,
    pub bind_rules_bytecode: Option<Vec<u8>>,
    pub driver_framework_version: Option<u8>,
    pub is_disabled: Option<bool>,
    /* private fields */
}
General information for a driver, used with both composite and normal drivers.

Fields

url: Option<String>

URL of the driver component.

name: Option<String>

Name of the driver, taken from the first field of the ZIRCON_DRIVER macro in the driver.

colocate: Option<bool>

If this is true then the driver should be colocated in its parent’s DriverHost.

package_type: Option<DriverPackageType>

The type of package this driver is in.

is_fallback: Option<bool>

If this is true then the driver is a fallback driver. Fallback drivers have a lesser priority for binding, so they will only be chosen for binding if there is no non-fallback driver that has matched.

device_categories: Option<Vec<DeviceCategory>>

Device categories

bind_rules_bytecode: Option<Vec<u8>>

Bind rules which declare set of constraints to evaluate in order to determine whether the driver indexer should bind this driver to a device.

driver_framework_version: Option<u8>

The version of the driver framework that this driver is using. Supported values are 1 (DFv1) and 2 (DFv2). If not provided, 1 is the assumed version.

is_disabled: Option<bool>

Whether the driver is disabled. If true, this driver is not chosen to bind to nodes.