pub struct DriverResumeRequest {
pub power_element_lease: Option<EventPair>,
}Fields
power_element_lease: Option<EventPair>Trait Implementations
Sourceimpl Debug for DriverResumeRequest
impl Debug for DriverResumeRequest
Sourceimpl Decode<DriverResumeRequest, DefaultFuchsiaResourceDialect> for DriverResumeRequest
impl Decode<DriverResumeRequest, DefaultFuchsiaResourceDialect> for DriverResumeRequest
Sourceimpl<T0: Encode<Optional<HandleType<EventPair, { _ }, 24579>>, DefaultFuchsiaResourceDialect>> Encode<DriverResumeRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Optional<HandleType<EventPair, { _ }, 24579>>, DefaultFuchsiaResourceDialect>> Encode<DriverResumeRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for DriverResumeRequest
impl Hash for DriverResumeRequest
Sourceimpl Ord for DriverResumeRequest
impl Ord for DriverResumeRequest
Sourcefn cmp(&self, other: &DriverResumeRequest) -> Ordering
fn cmp(&self, other: &DriverResumeRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DriverResumeRequest
impl PartialEq for DriverResumeRequest
Sourcefn eq(&self, other: &DriverResumeRequest) -> bool
fn eq(&self, other: &DriverResumeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DriverResumeRequest
impl PartialOrd for DriverResumeRequest
Sourceimpl ResourceTypeMarker for DriverResumeRequest
impl ResourceTypeMarker for DriverResumeRequest
Sourcetype Borrowed<'a> = &'a mut DriverResumeRequest
type Borrowed<'a> = &'a mut DriverResumeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DriverResumeRequest
impl TypeMarker for DriverResumeRequest
Sourcetype Owned = DriverResumeRequest
type Owned = DriverResumeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DriverResumeRequest
impl Standalone<DefaultFuchsiaResourceDialect> for DriverResumeRequest
impl StructuralPartialEq for DriverResumeRequest