pub struct NodeManagerAddNodeRequest {
pub node: Node2,
pub controller: ServerEnd<NodeControllerMarker>,
pub node_ref: Option<ServerEnd<NodeMarker>>,
}Fields
node: Node2controller: ServerEnd<NodeControllerMarker>node_ref: Option<ServerEnd<NodeMarker>>Trait Implementations
Sourceimpl Debug for NodeManagerAddNodeRequest
impl Debug for NodeManagerAddNodeRequest
Sourceimpl Decode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for NodeManagerAddNodeRequest
impl Decode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for NodeManagerAddNodeRequest
Sourceimpl Encode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for &mut NodeManagerAddNodeRequest
impl Encode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for &mut NodeManagerAddNodeRequest
Sourceimpl<T0: Encode<Node2, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<NodeControllerMarker>>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<Endpoint<ServerEnd<NodeMarker>>>, DefaultFuchsiaResourceDialect>> Encode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
impl<T0: Encode<Node2, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<NodeControllerMarker>>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<Endpoint<ServerEnd<NodeMarker>>>, DefaultFuchsiaResourceDialect>> Encode<NodeManagerAddNodeRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
Sourceimpl PartialEq for NodeManagerAddNodeRequest
impl PartialEq for NodeManagerAddNodeRequest
Sourcefn eq(&self, other: &NodeManagerAddNodeRequest) -> bool
fn eq(&self, other: &NodeManagerAddNodeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for NodeManagerAddNodeRequest
impl ResourceTypeMarker for NodeManagerAddNodeRequest
Sourcetype Borrowed<'a> = &'a mut NodeManagerAddNodeRequest
type Borrowed<'a> = &'a mut NodeManagerAddNodeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for NodeManagerAddNodeRequest
impl StructuralPartialEq for NodeManagerAddNodeRequest
Sourceimpl TypeMarker for NodeManagerAddNodeRequest
impl TypeMarker for NodeManagerAddNodeRequest
Sourcetype Owned = NodeManagerAddNodeRequest
type Owned = NodeManagerAddNodeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for NodeManagerAddNodeRequest
impl RefUnwindSafe for NodeManagerAddNodeRequest
impl Send for NodeManagerAddNodeRequest
impl Sync for NodeManagerAddNodeRequest
impl Unpin for NodeManagerAddNodeRequest
impl UnsafeUnpin for NodeManagerAddNodeRequest
impl UnwindSafe for NodeManagerAddNodeRequest