pub struct NodeManagerMarker;Trait Implementations
Sourceimpl Clone for NodeManagerMarker
impl Clone for NodeManagerMarker
Sourcefn clone(&self) -> NodeManagerMarker
fn clone(&self) -> NodeManagerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NodeManagerMarker
Sourceimpl Debug for NodeManagerMarker
impl Debug for NodeManagerMarker
Sourceimpl DiscoverableProtocolMarker for NodeManagerMarker
impl DiscoverableProtocolMarker for NodeManagerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for NodeManagerMarker
Sourceimpl Hash for NodeManagerMarker
impl Hash for NodeManagerMarker
Sourceimpl Ord for NodeManagerMarker
impl Ord for NodeManagerMarker
Sourcefn cmp(&self, other: &NodeManagerMarker) -> Ordering
fn cmp(&self, other: &NodeManagerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NodeManagerMarker
impl PartialEq for NodeManagerMarker
Sourcefn eq(&self, other: &NodeManagerMarker) -> bool
fn eq(&self, other: &NodeManagerMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for NodeManagerMarker
impl PartialOrd for NodeManagerMarker
Sourceimpl ProtocolMarker for NodeManagerMarker
impl ProtocolMarker for NodeManagerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.driver.framework.NodeManager"
const DEBUG_NAME: &'static str = "fuchsia.driver.framework.NodeManager"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = NodeManagerProxy
type Proxy = NodeManagerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = NodeManagerRequestStream
type RequestStream = NodeManagerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = NodeManagerSynchronousProxy
type SynchronousProxy = NodeManagerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for NodeManagerMarker