pub struct ResourceArgs {
pub name: Option<String>,
pub properties: Option<Vec<NodeProperty2>>,
pub offers: Option<Vec<Offer>>,
pub bus_info: Option<BusInfo>,
/* private fields */
}Expand description
Arguments for providing a resource.
Fields
name: Option<String>Name of the resource. Required.
properties: Option<Vec<NodeProperty2>>Properties of the resource. Required.
offers: Option<Vec<Offer>>Capabilities the resource offers to the node that depends on it. Required.
bus_info: Option<BusInfo>Information that feeds into a structured bus topology for the device. It should only be specified by bus drivers, ideally those which are included by default. Optional.