pub struct ResourceControllerMarker;Trait Implementations
Sourceimpl Clone for ResourceControllerMarker
impl Clone for ResourceControllerMarker
Sourcefn clone(&self) -> ResourceControllerMarker
fn clone(&self) -> ResourceControllerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceControllerMarker
impl Debug for ResourceControllerMarker
Sourceimpl Hash for ResourceControllerMarker
impl Hash for ResourceControllerMarker
Sourceimpl Ord for ResourceControllerMarker
impl Ord for ResourceControllerMarker
Sourcefn cmp(&self, other: &ResourceControllerMarker) -> Ordering
fn cmp(&self, other: &ResourceControllerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ResourceControllerMarker
impl PartialEq for ResourceControllerMarker
Sourcefn eq(&self, other: &ResourceControllerMarker) -> bool
fn eq(&self, other: &ResourceControllerMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ResourceControllerMarker
impl PartialOrd for ResourceControllerMarker
Sourceimpl ProtocolMarker for ResourceControllerMarker
impl ProtocolMarker for ResourceControllerMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) ResourceController"
const DEBUG_NAME: &'static str = "(anonymous) ResourceController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ResourceControllerProxy
type Proxy = ResourceControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ResourceControllerRequestStream
type RequestStream = ResourceControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ResourceControllerSynchronousProxy
type SynchronousProxy = ResourceControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ResourceControllerMarker
impl Eq for ResourceControllerMarker
impl StructuralPartialEq for ResourceControllerMarker